
#ifndef TCA_H__
#define TCA_H__

#include <stdint.h>
#include <string.h>
#include "nrf_gpio.h"
#include "ble_srv_common.h"
#include "app_error.h"
//ADDRESSES
#define TCA6057_ADDR   0x45
#define LSM303_ADDR    0b0011101
#define D20_SA0_HIGH_ADDRESS      0b1101011
#define D20_SA0_LOW_ADDRESS       0b1101010

//LED
#define sel0           0x00
#define sel1           0x01
#define sel2           0x02
#define fadeont        0x03
#define fullyont       0x04
#define fadeofft       0x05
#define ffullyofft     0x06
#define sfullyofft     0x07
#define maxinten       0x08
#define oneshotmi      0x09
#define initialization 0x0A

#define P1 0x00
#define P2 0x01
#define P3 0x02
#define P4 0x03
#define P5 0x04
#define P6 0x05
#define P7 0x06

#define pOff 0x00
#define OnPWM0 0x02
#define OnPWM1 0x03
#define pOn 0x04
#define Ononeshot 0x05
#define Flashbank0 0x06
#define Flashbank1 0x07

#define TMS0 0x00
#define TMS64 0x01
#define TMS128 0x02
#define TMS192 0x03
#define TMS256 0x04
#define TMS384 0x05
#define TMS512 0x06
#define TMS768 0x07
#define TMS1024 0x08
#define TMS1536 0x09
#define TMS2048 0x0A
#define TMS3072 0x0B
#define TMS4096 0x0C
#define TMS5760 0x0D
#define TMS8128 0x0E
#define TMS16320 0x0F

#define Bbank0 0x00
#define Bbank1 0x01

//ACCEL

#define CTRL0         0x1F
#define CTRL1         0x20
#define CTRL2         0x21
#define CTRL3         0x22
#define CTRL4         0x23
#define CTRL5         0x24
#define CTRL6         0x25
#define CTRL7         0x26

#define TIME_LIMIT    0x3B
#define CLICK_THS     0x3A
#define CLICK_SRC     0x39
#define CLICK_CFG     0x38

#define OUT_X_L_A     0x28
#define OUT_X_H_A     0x29
#define OUT_Y_L_A     0x2A
#define OUT_Y_H_A     0x2B
#define OUT_Z_L_A     0x2C
#define OUT_Z_H_A     0x2D
#define WHO_AM_I      0x0F


//GYRO

#define WHO_AM_I_G    0x0F

#define CTRL1G        0x20 // D20H
#define CTRL2G        0x21 // D20H
#define CTRL3G        0x22 // D20H
#define CTRL4G        0x23 // D20H
#define CTRL5G        0x24 // D20H
#define REFERENCE     0x25
#define OUT_TEMP      0x26
#define STATUS        0x27 // D20H
#define OUT_X_L_G     0x28
#define OUT_X_H_G     0x29
#define OUT_Y_L_G     0x2A
#define OUT_Y_H_G     0x2B
#define OUT_Z_L_G     0x2C
#define OUT_Z_H_G     0x2D

// #define FIFO_CTRL      = 0x2E, // D20H
// #define FIFO_SRC       = 0x2F, // D20H

// #define IG_CFG         = 0x30, // D20H
// #define IG_SRC         = 0x31, // D20H
// #define IG_THS_XH      = 0x32, // D20H
// #define IG_THS_XL      = 0x33, // D20H
// #define IG_THS_YH      = 0x34, // D20H
// #define IG_THS_YL      = 0x35, // D20H
// #define IG_THS_ZH      = 0x36, // D20H
// #define IG_THS_ZL      = 0x37, // D20H
// #define IG_DURATION    = 0x38, // D20H

#define LOW_ODR       0x39  // D20H

//TEMP
#define TEMP_ADDR    0x40



//TODO structs

//TODO add Wire.h style functionality
void     twi_init     (void);

//LED
void     writeTCA     (uint8_t * valToWrite, uint8_t numBytesToWrite);
uint8_t* readTCA      (uint8_t addrToRead,uint8_t numBytesToRead);

//ACCEL
void     writeAccel   (uint8_t * valToWrite, uint8_t numBytesToWrite);
uint8_t* readAccel    (uint8_t addrToRead,uint8_t numBytesToRead);
uint8_t  readAccelReg (uint8_t addrToRead);
int16_t* readAccelXYZ (void);
void     enableAccel  (void);
void     setClickCnfg (bool enable);
bool     checkIntrpt  (void);

//GYRO
void     writeGyro    (uint8_t * valToWrite, uint8_t numBytesToWrite);
uint8_t* readGyro     (uint8_t addrToRead,uint8_t numBytesToRead);
uint8_t  readGyroReg  (uint8_t addrToRead);
int16_t* readGyroXYZ  (void);
void     enableGyro   (void);

//TEMP
int32_t  readTemp     (void);

//UTIL
uint8_t  map16toU8    (int16_t sensorVal);
uint8_t  map16toNibble(int16_t sensorVal);


#endif 
